@@ -85,6 +85,7 @@ __all__ = (
     "MaintenanceWindowTaskInvocationParametersTypeDef",
     "MaintenanceWindowTaskParameterValueExpressionTypeDef",
     "MaintenanceWindowTaskTypeDef",
+    "MetadataValueTypeDef",
     "NonCompliantSummaryTypeDef",
     "NotificationConfigTypeDef",
     "OpsEntityItemTypeDef",
@@ -94,6 +95,7 @@ __all__ = (
     "OpsItemNotificationTypeDef",
     "OpsItemSummaryTypeDef",
     "OpsItemTypeDef",
+    "OpsMetadataTypeDef",
     "OutputSourceTypeDef",
     "ParameterHistoryTypeDef",
     "ParameterInlinePolicyTypeDef",
@@ -145,6 +147,7 @@ __all__ = (
     "CreateDocumentResultTypeDef",
     "CreateMaintenanceWindowResultTypeDef",
     "CreateOpsItemResponseTypeDef",
+    "CreateOpsMetadataResultTypeDef",
     "CreatePatchBaselineResultTypeDef",
     "DeleteInventoryResultTypeDef",
     "DeleteMaintenanceWindowResultTypeDef",
@@ -205,6 +208,7 @@ __all__ = (
     "GetMaintenanceWindowResultTypeDef",
     "GetMaintenanceWindowTaskResultTypeDef",
     "GetOpsItemResponseTypeDef",
+    "GetOpsMetadataResultTypeDef",
     "GetOpsSummaryResultTypeDef",
     "GetParameterHistoryResultTypeDef",
     "GetParameterResultTypeDef",
@@ -227,11 +231,13 @@ __all__ = (
     "ListDocumentVersionsResultTypeDef",
     "ListDocumentsResultTypeDef",
     "ListInventoryEntriesResultTypeDef",
+    "ListOpsMetadataResultTypeDef",
     "ListResourceComplianceSummariesResultTypeDef",
     "ListResourceDataSyncResultTypeDef",
     "ListTagsForResourceResultTypeDef",
     "MaintenanceWindowFilterTypeDef",
     "OpsItemFilterTypeDef",
+    "OpsMetadataFilterTypeDef",
     "OpsResultAttributeTypeDef",
     "PaginatorConfigTypeDef",
     "ParameterStringFilterTypeDef",
@@ -260,6 +266,7 @@ __all__ = (
     "UpdateMaintenanceWindowResultTypeDef",
     "UpdateMaintenanceWindowTargetResultTypeDef",
     "UpdateMaintenanceWindowTaskResultTypeDef",
+    "UpdateOpsMetadataResultTypeDef",
     "UpdatePatchBaselineResultTypeDef",
     "WaiterConfigTypeDef",
 )
@@ -1172,6 +1179,8 @@ MaintenanceWindowTaskTypeDef = TypedDict(
     total=False,
 )
 
+MetadataValueTypeDef = TypedDict("MetadataValueTypeDef", {"Value": str}, total=False)
+
 NonCompliantSummaryTypeDef = TypedDict(
     "NonCompliantSummaryTypeDef",
     {"NonCompliantCount": int, "SeveritySummary": "SeveritySummaryTypeDef"},
@@ -1262,6 +1271,18 @@ OpsItemTypeDef = TypedDict(
     total=False,
 )
 
+OpsMetadataTypeDef = TypedDict(
+    "OpsMetadataTypeDef",
+    {
+        "ResourceId": str,
+        "OpsMetadataArn": str,
+        "LastModifiedDate": datetime,
+        "LastModifiedUser": str,
+        "CreationDate": datetime,
+    },
+    total=False,
+)
+
 OutputSourceTypeDef = TypedDict(
     "OutputSourceTypeDef", {"OutputSourceId": str, "OutputSourceType": str}, total=False
 )
@@ -1341,6 +1362,7 @@ PatchBaselineIdentityTypeDef = TypedDict(
             "CENTOS",
             "ORACLE_LINUX",
             "DEBIAN",
+            "MACOS",
         ],
         "BaselineDescription": str,
         "DefaultBaseline": bool,
@@ -1850,6 +1872,10 @@ CreateOpsItemResponseTypeDef = TypedDict(
     "CreateOpsItemResponseTypeDef", {"OpsItemId": str}, total=False
 )
 
+CreateOpsMetadataResultTypeDef = TypedDict(
+    "CreateOpsMetadataResultTypeDef", {"OpsMetadataArn": str}, total=False
+)
+
 CreatePatchBaselineResultTypeDef = TypedDict(
     "CreatePatchBaselineResultTypeDef", {"BaselineId": str}, total=False
 )
@@ -2212,6 +2238,7 @@ GetDefaultPatchBaselineResultTypeDef = TypedDict(
             "CENTOS",
             "ORACLE_LINUX",
             "DEBIAN",
+            "MACOS",
         ],
     },
     total=False,
@@ -2388,6 +2415,12 @@ GetOpsItemResponseTypeDef = TypedDict(
     "GetOpsItemResponseTypeDef", {"OpsItem": "OpsItemTypeDef"}, total=False
 )
 
+GetOpsMetadataResultTypeDef = TypedDict(
+    "GetOpsMetadataResultTypeDef",
+    {"ResourceId": str, "Metadata": Dict[str, "MetadataValueTypeDef"], "NextToken": str},
+    total=False,
+)
+
 GetOpsSummaryResultTypeDef = TypedDict(
     "GetOpsSummaryResultTypeDef",
     {"Entities": List["OpsEntityTypeDef"], "NextToken": str},
@@ -2431,6 +2464,7 @@ GetPatchBaselineForPatchGroupResultTypeDef = TypedDict(
             "CENTOS",
             "ORACLE_LINUX",
             "DEBIAN",
+            "MACOS",
         ],
     },
     total=False,
@@ -2451,6 +2485,7 @@ GetPatchBaselineResultTypeDef = TypedDict(
             "CENTOS",
             "ORACLE_LINUX",
             "DEBIAN",
+            "MACOS",
         ],
         "GlobalFilters": "PatchFilterGroupTypeDef",
         "ApprovalRules": "PatchRuleGroupTypeDef",
@@ -2583,6 +2618,12 @@ ListInventoryEntriesResultTypeDef = TypedDict(
     total=False,
 )
 
+ListOpsMetadataResultTypeDef = TypedDict(
+    "ListOpsMetadataResultTypeDef",
+    {"OpsMetadataList": List["OpsMetadataTypeDef"], "NextToken": str},
+    total=False,
+)
+
 ListResourceComplianceSummariesResultTypeDef = TypedDict(
     "ListResourceComplianceSummariesResultTypeDef",
     {
@@ -2631,6 +2672,8 @@ OpsItemFilterTypeDef = TypedDict(
     },
 )
 
+OpsMetadataFilterTypeDef = TypedDict("OpsMetadataFilterTypeDef", {"Key": str, "Values": List[str]})
+
 OpsResultAttributeTypeDef = TypedDict("OpsResultAttributeTypeDef", {"TypeName": str})
 
 PaginatorConfigTypeDef = TypedDict(
@@ -2833,6 +2876,10 @@ UpdateMaintenanceWindowTaskResultTypeDef = TypedDict(
     total=False,
 )
 
+UpdateOpsMetadataResultTypeDef = TypedDict(
+    "UpdateOpsMetadataResultTypeDef", {"OpsMetadataArn": str}, total=False
+)
+
 UpdatePatchBaselineResultTypeDef = TypedDict(
     "UpdatePatchBaselineResultTypeDef",
     {
@@ -2848,6 +2895,7 @@ UpdatePatchBaselineResultTypeDef = TypedDict(
             "CENTOS",
             "ORACLE_LINUX",
             "DEBIAN",
+            "MACOS",
         ],
         "GlobalFilters": "PatchFilterGroupTypeDef",
         "ApprovalRules": "PatchRuleGroupTypeDef",
